changeset 3236:328132ed483c

(PTY_ITERATION, PTY_NAME_SPRINTF, PTY_TTY_NAME_SPRINTF): Redefined. (SIGNALS_VIA_CHARACTERS): Defined. [HAVE_SOCKETS] (HAVE_GETTIMEOFDAY): Defined. (MAIL_PROGRAM_NAME): Defined (two alternate definitions).
author Richard M. Stallman <rms@gnu.org>
date Sat, 29 May 1993 04:59:26 +0000
parents 82c4b81ce570
children b25509c0993b
files src/s/sco4.h
diffstat 1 files changed, 22 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/src/s/sco4.h	Sat May 29 04:53:57 1993 +0000
+++ b/src/s/sco4.h	Sat May 29 04:59:26 1993 +0000
@@ -38,21 +38,28 @@
 /* SCO has ptys with unusual names.  */
 #define HAVE_PTYS
 
+#define PTY_ITERATION \
+   for (i = 0; ; i++)
 #define PTY_NAME_SPRINTF \
-  sprintf (pty_name, "/dev/ptyp%d", ((c - FIRST_PTY_LETTER) * 16) + i);
+  sprintf (pty_name, "/dev/ptyp%d", i);
 #define PTY_TTY_NAME_SPRINTF \
-  sprintf (pty_name, "/dev/ttyp%d", ((c - FIRST_PTY_LETTER) * 16) + i);
+  sprintf (pty_name, "/dev/ttyp%d", i);
 
 /* SCO has bcopy, et. al.  */
 #define BSTRING
 
-/* Sockets are an option on SCO.  If we have X, we have them.  */
+/* Sockets are an option on SCO.  If you have X, you have them.
+   They also exist if you have TCP, but we don't know how to test
+   for that.  */
 #ifdef HAVE_X_WINDOWS
 #define HAVE_SOCKETS
 #endif
 
 #ifdef HAVE_SOCKETS
 #define LIBS_SYSTEM -lsocket
+
+/* SCO has gettimeofday in socket library */
+#define HAVE_GETTIMEOFDAY
 #endif
 
 /* We don't have -loldX, and we don't need it.  */
@@ -65,3 +72,15 @@
 /* We need to link with crt1.o and crtn.o.  */
 #define START_FILES pre-crt0.o /lib/crt1.o
 #define LIB_STANDARD -lc /lib/crtn.o
+
+/* Send signals to subprocesses by "typing" signal chars at them.  */
+#define SIGNALS_VIA_CHARACTERS
+
+/* Specify program for etc/fakemail to run.  Define SMAIL if you are
+   using smail, don't for MMDF.  */
+
+#ifdef SMAIL
+#define MAIL_PROGRAM_NAME "/bin/smail -q0"
+#else
+#define MAIL_PROGRAM_NAME "/usr/lib/mail/execmail"
+#endif